@@ -15,15 +15,15 @@
 #' @return
 #' The summary method returns a numeric matrix of summary statistics for each variable (invisibly for the print method), wheras the add.summary function returns an object of class \code{\link{runjags-class}} with the new sumamry statistics (and plots if selected) stored for future use.  Some summary statistics are only calculated for stochastic variables, but all monitored variables are shown in the output. The information returned as part of the summary is as follows:
 
-#' * LowerXX The lower confidence limit for the highest posterior density (HPD) credible interval, as calculated by \code{\link[coda]{HPDinterval}}. One or more confidence limits can be selected using the confidence argument - the default of 0.95 corresponds to 95\% credible intervals.
+#' * LowerXX The lower confidence limit for the highest posterior density (HPD) credible interval, as calculated by \code{\link[coda]{HPDinterval}}. One or more confidence limits can be selected using the confidence argument - the default of 0.95 corresponds to 95% credible intervals.
 #' * Median The median value, as calculated by \code{\link[stats]{median}}.
-#' * UpperXX The upper confidence limit for the highest posterior density (HPD) credible interval, as calculated by \code{\link[coda]{HPDinterval}}. One or more confidence limits can be selected using the confidence argument - the default of 0.95 corresponds to 95\% credible intervals.
+#' * UpperXX The upper confidence limit for the highest posterior density (HPD) credible interval, as calculated by \code{\link[coda]{HPDinterval}}. One or more confidence limits can be selected using the confidence argument - the default of 0.95 corresponds to 95% credible intervals.
 #' * Mean The mean value, as calculated by \code{\link[base]{mean}}.
 #' * SD The sample standard deviation, derived from \code{\link[stats]{var}}.
 #' * Mode The mode of the variable. For discrete variables this is calculated using \code{\link[base]{table}}, and for continuous variables by \code{\link[modeest]{mlv}} if this package is installed - see the modeest.opts argument for more details.
 #' * MCerr The Monte Carlo standard error associated with this variable, which is the standard error divided by the square root of the effective sample size as caulculated by \code{\link[coda]{effectiveSize}}.
-#' * MC\%ofSD The Monte Carlo standard error expressed as a percentage of the standard deviation of the variable - a rule of thumb is that this should be less than approximately 5\%.
-#' * SSeff The effective sample size as caulculated by \code{\link[coda]{effectiveSize}}.  An effective sample size of over 400 should correspond to an MCerr of less than 5\% of the sample standard deviation.
+#' * MC%ofSD The Monte Carlo standard error expressed as a percentage of the standard deviation of the variable - a rule of thumb is that this should be less than approximately 5%.
+#' * SSeff The effective sample size as caulculated by \code{\link[coda]{effectiveSize}}.  An effective sample size of over 400 should correspond to an MCerr of less than 5% of the sample standard deviation.
 #' * AC.XX The autocorrelation of the sample, as calculated by \code{\link[coda]{autocorr.diag}}.  One or more lag values can be specified using the autocorr.lags argument - the default is 10 iterations.
 #' * psrf The potential scale reduction factor of the Gelman-Rubin statistic autocorrelation of the sample, as calculated by \code{\link[coda]{autocorr.diag}}.  This is sometimes referred to as Rhat (or R-hat).  Note that any variables marked with a $ sign were stochastic in some chains but not in others - this usually indicates a problem with the model or sampler.
 
@@ -428,7 +428,7 @@ print.runjags <- function(x, vars=NA, digits = 5, ...){
 				if(any(x$semistochastic) && niter(x$mcmc)>1)
 					cat("Note: parameters marked with '$' were non-stochastic in some chains - these parameters can not be assumed to have converged!\n")
 
-				if(class(x$dic)!="character"){
+				if(!is.character(x$dic)){
           if(is.na(x$dic$dic)){
 					  cat("[DIC not available from the stored object]\n", sep="")
 	        }else{
@@ -475,7 +475,7 @@ print.runjagsplots <- function(x,layout=runjags.getOption('plot.layout'),new.win
 		newwindows <- FALSE
 	}
 
-	if(class(x)=="runjags"){
+	if(inherits(x, "runjags")){
 
 		x <- checkvalidrunjagsobject(x)
 
@@ -489,7 +489,7 @@ print.runjagsplots <- function(x,layout=runjags.getOption('plot.layout'),new.win
 		# vars=NA and type= here combined with return if all character above should ensure they are never re-plotted
 	}
 
-	if(class(x)=='runjagsplots' && !all(sapply(x,class)=='trellis')){
+	if(inherits(x, 'runjagsplots') && !all(sapply(x,inherits, what='trellis'))){
 		# If we are directly invoking the print method for $trace we may to sort out the possible list of separate chains
 		# If called from plot(rjo) then we are passed a list, and the separating of separate chains has already been done
 		x <- lapply(x, function(todo){
@@ -500,7 +500,7 @@ print.runjagsplots <- function(x,layout=runjags.getOption('plot.layout'),new.win
 			})
 	}
 
-	if(class(x)=="character"){
+	if(inherits(x, "character")){
 		cat(x)
 		invisible(x)
 	}
